@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use vars    qw[@ISA $STATUS $VERSION];
 use base    'CPANPLUS::Dist::Base';
-$VERSION = "0.9160";
+$VERSION = "0.9166";
 
 use CPANPLUS::Internals::Constants;
 use CPANPLUS::Internals::Constants::Report;
@@ -261,6 +261,9 @@ sub prepare {
     my $fail;
     RUN: {
 
+        local $ENV{PERL_USE_UNSAFE_INC} = 1
+          unless exists $ENV{PERL_USE_UNSAFE_INC};
+
         ### we resolve 'configure requires' here, so we can run the 'perl
         ### Makefile.PL' command
         ### XXX for tests: mock f_c_r to something that *can* resolve and
@@ -355,7 +358,7 @@ sub prepare {
             ### in @INC, stopping us from resolving dependencies on CPANPLUS
             ### at bootstrap time properly.
 
-            my @run_perl    = ( '-e', PERL_WRAPPER );
+            my @run_perl    = ( '-MCPANPLUS::Internals::Utils::Autoflush' );
             my $cmd         = [$perl, @run_perl, $makefile_pl, @mmflags];
 
             ### set ENV var to tell underlying code this is what we're
@@ -610,6 +613,10 @@ sub create {
     my $fail; my $prereq_fail; my $test_fail;
     my $status = { };
     RUN: {
+
+        local $ENV{PERL_USE_UNSAFE_INC} = 1
+          unless exists $ENV{PERL_USE_UNSAFE_INC};
+
         ### this will set the directory back to the start
         ### dir, so we must chdir /again/
         my $ok = $dist->_resolve_prereqs(
@@ -832,6 +839,9 @@ sub install {
 
     my $fail; my $captured;
 
+    local $ENV{PERL_USE_UNSAFE_INC} = 1
+      unless exists $ENV{PERL_USE_UNSAFE_INC};
+
     ### 'make install' section ###
     ### XXX need makeflags here too?
     ### yes, but they should really be split out.. see bug #4143
